Summary: An XML parser library
Name: expat
Version: 2.2.7
Release: 1
Group: System Environment/Libraries
Source0: http://download.sourceforge.net/%{name}/%{name}-%{version}.tar.bz2
Source1: libexpat.so.0-aix32
Source2: libexpat.so.0-aix64
Source10: http://download.sourceforge.net/%{name}/%{name}-%{version}.tar.bz2.asc
Patch0: %{name}-%{version}-aix.patch
URL: http://www.libexpat.org/
License: MIT
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

%define _libdir64 %{_prefix}/lib64

%description
This is expat, the C library for parsing XML, written by James Clark. Expat
is a stream oriented XML parser. This means that you register handlers with
the parser prior to starting the parse. These handlers are called when the
parser discovers the associated structures in the document being parsed. A
start tag is an example of the kind of structures for which you may
register handlers.

The library is available as 32-bit and 64-bit.


%package devel
Summary: Libraries and header files to develop applications using expat
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
The expat-devel package contains the libraries, include files and documentation
to develop XML applications with expat.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "cc_r -q64" or "gcc -maix64".


%prep
%setup -q
#%patch0
# fake a <stdbool.h> as AIX5L V5.1 and XLC/C++ V7 doesn't have one
cat > stdbool.h << EOF
#ifndef stdbool_h_wrapper
#define stdbool_h_wrapper

typedef enum {false = 0, true = 1} bool;

#endif
EOF
mkdir ../32bit
mv * ../32bit
mv ../32bit .
mkdir 64bit
cd 32bit && tar cf - . | (cd ../64bit ; tar xpf -)


%build
export CC="cc_r -qcpluscmt"

export DOCBOOK_TO_MAN="xmlto man --skip-validation"

cd 64bit
# first build the 64-bit version
export OBJECT_MODE=64
./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir64} \
    --mandir=%{_mandir} \
    --enable-shared --enable-static
make %{?_smp_mflags}

cd ../32bit
# now build the 32-bit version
export OBJECT_MODE=32
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --enable-shared --enable-static
make %{?_smp_mflags}


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

for i in 32bit 64bit ; do
    cd ${i}
    rm -f examples/*.dsp
    chmod 644 README.md COPYING Changes doc/* examples/*
    cd ..
done

cd 64bit
export OBJECT_MODE=64
make DESTDIR=${RPM_BUILD_ROOT} install

(
  cd ${RPM_BUILD_ROOT}%{_bindir}
  for f in * ; do
    mv -f ${f} ${f}_64
  done
)

cd ../32bit
export OBJECT_MODE=32
make DESTDIR=${RPM_BUILD_ROOT} install

/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/* || :

(
  cd ${RPM_BUILD_ROOT}%{_libdir64}
  for f in *.a ; do
    /usr/bin/ar -X64 -x ${f}
  done

  cd ${RPM_BUILD_ROOT}%{_libdir}
  for f in *.a ; do
    /usr/bin/ar -X32 -x ${f}
  done
)

# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/lib%{name}.a ${RPM_BUILD_ROOT}%{_libdir64}/lib%{name}.so*

# Add the older libexpat.so.0 shared members for compatibility with older apps
# (make sure they're set for LOADONLY with 'strip -e')
/usr/bin/strip -X32 -e %{SOURCE1}
/usr/bin/strip -X64 -e %{SOURCE2}
cp %{SOURCE1} libexpat.so.0
/usr/bin/ar -X32 -q ${RPM_BUILD_ROOT}%{_libdir}/lib%{name}.a libexpat.so.0
cp %{SOURCE2} libexpat.so.0
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/lib%{name}.a libexpat.so.0

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib lib64
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system)
%doc 32bit/README.md 32bit/COPYING
%{_bindir}/*
%{_libdir}/*.a
%{_libdir}/*.so*
%{_libdir64}/*.so*
%{_mandir}/man?/*
/usr/bin/*
/usr/lib/*.a
/usr/lib/*.so*
/usr/lib64/*.so*


%files devel
%defattr(-,root,system)
%doc 32bit/Changes 32bit/doc 32bit/examples
%{_libdir}/*.la
%{_libdir64}/*.la
%{_libdir}/pkgconfig/*.pc
%{_libdir64}/pkgconfig/*.pc
%{_includedir}/*.h
/usr/include/*
/usr/lib/*.la
/usr/lib64/*.la


%changelog
* Fri Jun 28 2019 Michael Perzl <michael@perzl.org> - 2.2.7-1
- updated to version 2.2.7

* Mon Aug 20 2018 Michael Perzl <michael@perzl.org> - 2.2.6-1
- updated to version 2.2.6

* Thu Nov 16 2017 Michael Perzl <michael@perzl.org> - 2.2.5-1
- updated to version 2.2.5

* Thu Sep 07 2017 Michael Perzl <michael@perzl.org> - 2.2.4-1
- updated to version 2.2.4
- added run-time-linking shared objects

* Wed Aug 09 2017 Michael Perzl <michael@perzl.org> - 2.2.3-1
- updated to version 2.2.3

* Mon Jul 17 2017 Michael Perzl <michael@perzl.org> - 2.2.2-1
- updated to version 2.2.2

* Wed Jun 21 2017 Michael Perzl <michael@perzl.org> - 2.2.1-1
- updated to version 2.2.1

* Wed Nov 16 2016 Michael Perzl <michael@perzl.org> - 2.2.0-1
- updated to version 2.2.0

* Fri Mar 18 2016 Michael Perzl <michael@perzl.org> - 2.1.1-1
- updated to version 2.1.1

* Thu Apr 19 2012 Michael Perzl <michael@perzl.org> - 2.1.0-1
- updated to version 2.1.0

* Tue Jan 11 2011 Michael Perzl <michael@perzl.org> - 2.0.1-3
- added two security patches from Fedora

* Tue Oct 21 2008 Michael Perzl <michael@perzl.org> - 2.0.1-2
- added compatibility shared objects for the AIX Toolbox version of expat

* Mon Mar 31 2008 Michael Perzl <michael@perzl.org> - 2.0.1-1
- first version for AIX V5.1 and higher
